Options class

SDK configuration options.

Use this class to configure the SDK behavior.

Example

final options = Options()
  ..mirror = true
  ..debug = false;

TgoRTC.instance.init(options);

Constructors

Options()

Properties

debug bool
Whether to enable debug logging.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mirror bool
Whether to mirror local video (front camera).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited