RoomInfo class

Room connection information.

Contains all the information needed to connect to a LiveKit room.

Example

final roomInfo = RoomInfo(
  'my-room',
  'access-token',
  'wss://livekit.example.com',
  'user-123',
  'creator-456',
);

Constructors

RoomInfo(String roomName, String token, String url, String loginUID, String creatorUID)
Creates a new RoomInfo instance.

Properties

creatorUID String
The UID of the room creator.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isP2P bool
Whether this is a P2P (peer-to-peer) call.
getter/setter pair
loginUID String
The UID of the current logged-in user.
getter/setter pair
maxParticipants int
Maximum number of participants allowed in the room.
getter/setter pair
roomName String
The name of the room.
getter/setter pair
rtcType RTCType
The type of RTC call (audio or video).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout int
Timeout in seconds for waiting for participants to join.
getter/setter pair
token String
The access token for authentication.
getter/setter pair
uidList List<String>
List of participant UIDs in the room.
getter/setter pair
url String
The LiveKit server URL (e.g., "wss://livekit.example.com").
getter/setter pair

Methods

getP2PToUID() String
Gets the UID of the other participant in a P2P call.
isCreator() bool
Returns true if the current user is the room creator.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited