VideoInfo class
Video stream information (for both local and remote streams).
Contains resolution, bitrate, frame rate, and quality information.
Constructors
Properties
- bitrate → int
-
Current bitrate in bits per second (bps).
final
- bitrateString → String
-
Returns formatted bitrate string (Kbps or Mbps).
no setter
- frameRate → double
-
Current frame rate.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → int
-
Video height in pixels.
final
- isValid → bool
-
Returns true if the video info contains valid data.
no setter
- layerId → String?
-
Current layer identifier (e.g., "f", "h", "q" for full, half, quarter).
final
- qualityLimitationReason → String?
-
Quality limitation reason (bandwidth, cpu, other, none).
final
- resolutionString → String
-
Returns formatted resolution string (e.g., "1920x1080").
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
Video width in pixels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override